==> jc-1.4.0.tar.gz: soot/options/ProfilingOptions.h <==
// public class soot.options.ProfilingOptions

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 52474ccb239e05f8 soot_options_ProfilingOptions

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_options_ProfilingOptions_H_
#define _JC_soot_options_ProfilingOptions_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Map$object;

// Typedefs
typedef struct _jc_soot_options_ProfilingOptions$sub_refs	_jc_soot_options_ProfilingOptions$sub_refs;
typedef struct _jc_soot_options_ProfilingOptions$sub_nonrefs	_jc_soot_options_ProfilingOptions$sub_nonrefs;
typedef struct _jc_soot_options_ProfilingOptions$refs	_jc_soot_options_ProfilingOptions$refs;
typedef struct _jc_soot_options_ProfilingOptions$nonrefs	_jc_soot_options_ProfilingOptions$nonrefs;
typedef struct _jc_soot_options_ProfilingOptions$object	_jc_soot_options_ProfilingOptions$object;

typedef const struct _jc_soot_options_ProfilingOptions$vmethods	_jc_soot_options_ProfilingOptions$vmethods;
typedef const struct _jc_soot_options_ProfilingOptions$vtable	_jc_soot_options_ProfilingOptions$vtable;
typedef const struct _jc_soot_options_ProfilingOptions$vtype	_jc_soot_options_ProfilingOptions$vtype;

// Constructors
extern void _jc_soot_options_ProfilingOptions$method$_init$39bc1e191d75104e(_jc_env *, struct _jc_soot_options_ProfilingOptions$object *, struct _jc_object *);

// Virtual methods
extern jboolean _jc_soot_options_ProfilingOptions$method$enabled$e29aaa88d18be18b(_jc_env *, struct _jc_soot_options_ProfilingOptions$object *);
extern jboolean _jc_soot_options_ProfilingOptions$method$notmainentry$3b59b7264203a7a1(_jc_env *, struct _jc_soot_options_ProfilingOptions$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_options_ProfilingOptions$method_info$enabled$e29aaa88d18be18b;
extern _jc_method _jc_soot_options_ProfilingOptions$method_info$notmainentry$3b59b7264203a7a1;

// Virtual methods structure
struct _jc_soot_options_ProfilingOptions$vmethods {
	jboolean	(*enabled$e29aaa88d18be18b)(_jc_env *, struct _jc_soot_options_ProfilingOptions$object *);
	jboolean	(*notmainentry$3b59b7264203a7a1)(_jc_env *, struct _jc_soot_options_ProfilingOptions$object *);
};

// Vtable
struct _jc_soot_options_ProfilingOptions$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_options_ProfilingOptions$vmethods	soot_options_ProfilingOptions;
};

// Vtype
struct _jc_soot_options_ProfilingOptions$vtype {
	_jc_type			type;
	_jc_soot_options_ProfilingOptions$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_options_ProfilingOptions$sub_refs {
	struct _jc_object	*options;
};

// Reference instance fields (object)
struct _jc_soot_options_ProfilingOptions$refs {
    _jc_soot_options_ProfilingOptions$sub_refs	soot_options_ProfilingOptions;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_options_ProfilingOptions$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_options_ProfilingOptions$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_options_ProfilingOptions$sub_nonrefs	soot_options_ProfilingOptions;
};

// Object instance structure
struct _jc_soot_options_ProfilingOptions$object {
	_jc_soot_options_ProfilingOptions$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_options_ProfilingOptions$vtype	*vtype;
	_jc_soot_options_ProfilingOptions$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_options_ProfilingOptions$vtype _jc_soot_options_ProfilingOptions$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_options_ProfilingOptions, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_options_ProfilingOptions$class_object;

#endif	/* _JC_soot_options_ProfilingOptions_H_ */

==> jc-1.4.6.tar.gz: soot/options/ProfilingOptions.h <==
// public class soot.options.ProfilingOptions

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 52474ccb239e05f8 soot_options_ProfilingOptions

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_options_ProfilingOptions_H_
#define _JC_soot_options_ProfilingOptions_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Map$object;

// Typedefs
typedef struct _jc_soot_options_ProfilingOptions$sub_refs	_jc_soot_options_ProfilingOptions$sub_refs;
typedef struct _jc_soot_options_ProfilingOptions$sub_nonrefs	_jc_soot_options_ProfilingOptions$sub_nonrefs;
typedef struct _jc_soot_options_ProfilingOptions$refs	_jc_soot_options_ProfilingOptions$refs;
typedef struct _jc_soot_options_ProfilingOptions$nonrefs	_jc_soot_options_ProfilingOptions$nonrefs;
typedef struct _jc_soot_options_ProfilingOptions$object	_jc_soot_options_ProfilingOptions$object;

typedef const struct _jc_soot_options_ProfilingOptions$vmethods	_jc_soot_options_ProfilingOptions$vmethods;
typedef const struct _jc_soot_options_ProfilingOptions$vtable	_jc_soot_options_ProfilingOptions$vtable;
typedef const struct _jc_soot_options_ProfilingOptions$vtype	_jc_soot_options_ProfilingOptions$vtype;

// Constructors
extern void _jc_soot_options_ProfilingOptions$method$_init$39bc1e191d75104e(_jc_env *, struct _jc_soot_options_ProfilingOptions$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_options_ProfilingOptions$method$enabled$e29aaa88d18be18b(_jc_env *, struct _jc_soot_options_ProfilingOptions$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_options_ProfilingOptions$method$notmainentry$3b59b7264203a7a1(_jc_env *, struct _jc_soot_options_ProfilingOptions$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_options_ProfilingOptions$method_info$enabled$e29aaa88d18be18b;
extern _jc_method _jc_soot_options_ProfilingOptions$method_info$notmainentry$3b59b7264203a7a1;

// Virtual methods structure
struct _jc_soot_options_ProfilingOptions$vmethods {
	jboolean	(*enabled$e29aaa88d18be18b)(_jc_env *, struct _jc_soot_options_ProfilingOptions$object *) _JC_JCNI_ATTR;
	jboolean	(*notmainentry$3b59b7264203a7a1)(_jc_env *, struct _jc_soot_options_ProfilingOptions$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_options_ProfilingOptions$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_options_ProfilingOptions$vmethods	soot_options_ProfilingOptions;
};

// Vtype
struct _jc_soot_options_ProfilingOptions$vtype {
	_jc_type			type;
	_jc_soot_options_ProfilingOptions$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_options_ProfilingOptions$sub_refs {
	struct _jc_object	*options;
};

// Reference instance fields (object)
struct _jc_soot_options_ProfilingOptions$refs {
    _jc_soot_options_ProfilingOptions$sub_refs	soot_options_ProfilingOptions;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_options_ProfilingOptions$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_options_ProfilingOptions$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_options_ProfilingOptions$sub_nonrefs	soot_options_ProfilingOptions;
};

// Object instance structure
struct _jc_soot_options_ProfilingOptions$object {
	_jc_soot_options_ProfilingOptions$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_options_ProfilingOptions$vtype	*vtype;
	_jc_soot_options_ProfilingOptions$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_options_ProfilingOptions$vtype _jc_soot_options_ProfilingOptions$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_options_ProfilingOptions, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_options_ProfilingOptions$class_object;

#endif	/* _JC_soot_options_ProfilingOptions_H_ */
